@@ -1,3 +1,6 @@
+//! Contains the [`SinglyLinkedList`]'s [`Node`], the [`Node`] contains the `value`s & `ptr`s of all elements within the list.
+
+
 use std::boxed::Box;
 use core::option::Option;
 use core::cmp::PartialEq;
@@ -7,7 +10,10 @@ use core::fmt;
 
 /// [`Node`] for representing values in a [`SinglyLinkedList`].
 pub struct Node<T> {
+    /// Next [`Node`] within the [`SinglyLinkedList`].
     pub next: Option<NonNull<Node<T>>>,
+
+    /// Value of the [`Node`].
     pub value: T,
 }
 
@@ -40,6 +46,23 @@ impl<T> Node<T> {
     pub fn into_box(self) -> Box<Self> {
         return Box::new(self);
     }
+
+    /// Converts the [`Node`] into a [`Box`], then converts the [`Box`] into a [`NonNull`] of the [`Node`].
+    /// 
+    /// ## Example
+    /// ```rust
+    /// let ptr = Node::new(5).into_non_null();
+    /// let value = unsafe { &ptr.as_ref().value };
+    /// 
+    /// assert_eq!(value, &5);
+    /// ```
+    /// 
+    /// ## Safety
+    /// - Converts the [`Node`] into a [`Box`] before [`NonNull`] conversion, `ptr` should always be valid.
+    #[inline]
+    pub fn into_non_null(self) -> NonNull<Self> {
+        return unsafe { NonNull::new_unchecked(Box::into_raw(self.into_box())) };
+    }
 }
 
 
